@@ -7,12 +7,13 @@ use std::{
     path::{Path, PathBuf},
 };
 
-use crate::emoji;
+use crate::info;
 
 pub const CONFIG_FILE_NAME: &str = "cargo-generate.toml";
 
 #[derive(Deserialize, Default)]
 pub struct AppConfig {
+    pub defaults: Option<DefaultsConfig>,
     pub favorites: Option<HashMap<String, FavoriteConfig>>,
     pub values: Option<HashMap<String, toml::Value>>,
 }
@@ -27,19 +28,22 @@ pub struct FavoriteConfig {
     pub values: Option<HashMap<String, toml::Value>>,
 }
 
-impl AppConfig {
-    pub(crate) fn from_path(path: &Path) -> Result<Self> {
+#[derive(Deserialize, Default)]
+pub struct DefaultsConfig {
+    /// relates to `crate::Args::ssh_identity`
+    pub ssh_identity: Option<PathBuf>,
+}
+
+impl TryFrom<&Path> for AppConfig {
+    type Error = anyhow::Error;
+
+    fn try_from(path: &Path) -> Result<Self, Self::Error> {
         if path.exists() {
             let cfg = fs::read_to_string(path)?;
             Ok(if cfg.trim().is_empty() {
                 Self::default()
             } else {
-                println!(
-                    "{} {} {}",
-                    emoji::INFO,
-                    style("Using application config:").bold(),
-                    style(path.display()).underlined()
-                );
+                info!("Using application config: {}", style(path.display()).bold());
                 toml::from_str(&cfg)?
             })
         } else {
@@ -53,7 +57,8 @@ impl AppConfig {
 }
 
 pub fn app_config_path(path: &Option<PathBuf>) -> Result<PathBuf> {
-    path.clone()
+    path.as_ref()
+        .map(|p| p.canonicalize().unwrap())
         .or_else(|| {
             home::cargo_home().map_or(None, |home| {
                 let preferred_path = home.join(CONFIG_FILE_NAME);
